function [U,B,V] = bidiag(A);
% BIDIAG Bidiagonalization of a matrix.
%
% B = bidiag(A);
% [U,B,V] = bidiag(A);
% [U,B] = bidiag(A);

% Computes the bidiagonalization of the m-times-n matrix A:
% A = U*B*V' ,
% where B is an upper bidiagonal square matrix, and U and
% V have orthogonal columns.
%
% Economy size matrices are obatined by adding a zeros for
% the second input argument.
%
% B = bidiag(A,0);
% [U,B,V] = bidiag(A,0);
% [U,B] = bidiag(A,0);

% Reference: L. Elden, "Algorithms for regularization of ill-
% conditioned least-squares problems", BIT 17 (1977), 134-145.
%
% Revision history:
% o For Matalb, m >= n: 
% Per Christian Hansen, UNI-C, 03/11/92.
% o For Matlab, m >= n and m < n:
% Martin Andersson, Foss Japan, 2011-08-11
% o C-code compiled Matlab mex-file:
% Martin Andersson, Foss Japan, 2011-09-06
% o C-code for full/economy size done:
% Martin Andersson, Foss Japan, 2011-09-10